@@ -62,9 +62,11 @@ module Graphics.GL.Core33 (
   pattern GL_BGRA_INTEGER,
   pattern GL_BGR_INTEGER,
   pattern GL_BLEND,
+  pattern GL_BLEND_COLOR,
   pattern GL_BLEND_DST,
   pattern GL_BLEND_DST_ALPHA,
   pattern GL_BLEND_DST_RGB,
+  pattern GL_BLEND_EQUATION,
   pattern GL_BLEND_EQUATION_ALPHA,
   pattern GL_BLEND_EQUATION_RGB,
   pattern GL_BLEND_SRC,
