@@ -19,6 +19,8 @@ module Graphics.GL.EXT.Semaphore (
   pattern GL_DEVICE_UUID_EXT,
   pattern GL_DRIVER_UUID_EXT,
   pattern GL_LAYOUT_COLOR_ATTACHMENT_EXT,
+  pattern GL_LAYOUT_DEPTH_ATTACHMENT_STENCIL_READ_ONLY_EXT,
+  pattern GL_LAYOUT_DEPTH_READ_ONLY_STENCIL_ATTACHMENT_EXT,
   pattern GL_LAYOUT_DEPTH_STENCIL_ATTACHMENT_EXT,
   pattern GL_LAYOUT_DEPTH_STENCIL_READ_ONLY_EXT,
   pattern GL_LAYOUT_GENERAL_EXT,
