@@ -19,6 +19,7 @@ module Graphics.GL.KHR (
   module Graphics.GL.KHR.DebugCompatibility,
   module Graphics.GL.KHR.DebugCore,
   module Graphics.GL.KHR.NoError,
+  module Graphics.GL.KHR.ParallelShaderCompile,
   module Graphics.GL.KHR.Robustness,
   module Graphics.GL.KHR.TextureCompressionASTCHDR,
   module Graphics.GL.KHR.TextureCompressionASTCLDR
@@ -30,6 +31,7 @@ import Graphics.GL.KHR.ContextFlushControl
 import Graphics.GL.KHR.DebugCompatibility
 import Graphics.GL.KHR.DebugCore
 import Graphics.GL.KHR.NoError
+import Graphics.GL.KHR.ParallelShaderCompile
 import Graphics.GL.KHR.Robustness
 import Graphics.GL.KHR.TextureCompressionASTCHDR
 import Graphics.GL.KHR.TextureCompressionASTCLDR
