@@ -86,9 +86,11 @@ module Graphics.GL.Version15 (
   pattern GL_BITMAP,
   pattern GL_BITMAP_TOKEN,
   pattern GL_BLEND,
+  pattern GL_BLEND_COLOR,
   pattern GL_BLEND_DST,
   pattern GL_BLEND_DST_ALPHA,
   pattern GL_BLEND_DST_RGB,
+  pattern GL_BLEND_EQUATION,
   pattern GL_BLEND_SRC,
   pattern GL_BLEND_SRC_ALPHA,
   pattern GL_BLEND_SRC_RGB,
